@@ -37,7 +37,6 @@ obtained by querying the cloud.
 import argparse
 import logging
 import os
-import six
 import sys
 
 import openstack
@@ -83,22 +82,22 @@ def load_basic_defaults(conf):
             ("log_file", "tempest.log")
         ],
         "identity": [
-            ("username", "demo"),
+            ("username", "demo_tempestconf"),
             ("password", "secrete"),
             ("project_name", "demo"),
-            ("alt_username", "alt_demo"),
+            ("project_domain_name", "Default"),
+            ("user_domain_name", "Default"),
+            ("alt_username", "alt_demo_tempestconf"),
             ("alt_password", "secrete"),
-            ("alt_project_name", "alt_demo"),
-            ("disable_ssl_certificate_validation", "true")
-        ],
-        "scenario": [
-            ("img_dir", "etc")
+            ("alt_project_name", "alt_demo")
         ],
         "auth": [
-            ("tempest_roles", "_member_"),
+            ("tempest_roles", "member"),
             ("admin_username", "admin"),
             ("admin_project_name", "admin"),
-            ("admin_domain_name", "Default")
+            ("admin_domain_name", "Default"),
+            ("admin_project_domain_name", "Default"),
+            ("admin_user_domain_name", "Default")
         ],
         "object-storage": [
             ("reseller_admin_role", "ResellerAdmin")
@@ -107,13 +106,16 @@ def load_basic_defaults(conf):
             ("lock_path", "/tmp")
         ],
         "compute-feature-enabled": [
-            # Default deployment does not use shared storage
-            ("live_migration", "false"),
-            ("live_migrate_paused_instances", "true"),
             ("preserve_ports", "true")
         ],
         "network-feature-enabled": [
             ("ipv6_subnet_attributes", "true")
+        ],
+        "scenario": [
+            # Since cirros version 0.6.0, dhcpcd dhcp client is the default
+            # and because tempestconf sets default cirros >= 0.6.0 by default,
+            # we can also set the dhcp client to dhcpcd by default
+            ("dhcp_client", "dhcpcd")
         ]}
 
     for section in default_values.keys():
@@ -133,10 +135,12 @@ def read_deployer_input(deployer_input_file, conf):
     """
     LOG.info("Adding options from deployer-input file '%s'",
              deployer_input_file)
-    if six.PY3:
-        deployer_input = configparser.ConfigParser()
-    else:
-        deployer_input = configparser.SafeConfigParser()
+    deployer_input = configparser.ConfigParser()
+    # the following transforms the option names as found in an input file,
+    # the default implementation returns a lower-case version of the
+    # option names, however, we have at least one option that contains
+    # capitalized letters - RBAC_test_type from octavia-tempest-plugin
+    deployer_input.optionxform = str
     deployer_input.read(deployer_input_file)
     for section in deployer_input.sections():
         # There are no deployer input options in DEFAULT
@@ -175,12 +179,10 @@ def set_options(conf, deployer_input, non_admin, image_path, overrides=[],
     conf.set('image', 'image_path', image_path)
 
     if deployer_input and os.path.isfile(deployer_input):
-        LOG.info("Reading deployer input from file {}".format(
-            deployer_input))
+        LOG.info("Reading deployer input from file %s", deployer_input)
         read_deployer_input(deployer_input, conf)
     elif os.path.isfile(C.DEPLOYER_INPUT) and not no_default_deployer:
-        LOG.info("Reading deployer input from file {}".format(
-            C.DEPLOYER_INPUT))
+        LOG.info("Reading deployer input from file %s", C.DEPLOYER_INPUT)
         read_deployer_input(C.DEPLOYER_INPUT, conf)
 
     if non_admin:
@@ -207,7 +209,6 @@ def set_options(conf, deployer_input, non_admin, image_path, overrides=[],
 
     uri = conf.get("identity", "uri")
     if "v3" in uri:
-        conf.set("identity", "auth_version", "v3")
         conf.set("identity", "uri_v3", uri)
     else:
         # TODO(arxcruz) make a check if v3 is enabled
@@ -306,6 +307,10 @@ def get_arg_parser():
                                 glance if it's not already there. The name of
                                 the image is the leaf name of the path. Default
                                 is '%s'""" % C.DEFAULT_IMAGE)
+    parser.add_argument('--retry-image', default=False, action='store_true',
+                        help="""Allow tempestconf to retry download an image,
+                                in case of failure, from these urls: '%s'
+                                """ % C.DEFAULT_IMAGES)
     parser.add_argument('--flavor-min-mem', default=C.DEFAULT_FLAVOR_RAM,
                         type=int, help="""Specify minimum memory for new
                         flavours, default is '%s'.""" % C.DEFAULT_FLAVOR_RAM)
@@ -316,8 +321,11 @@ def get_arg_parser():
                         help="""Convert images to raw format before uploading
                                 to glance.""")
     parser.add_argument('--network-id',
-                        help="""Specify which network with external connectivity
-                                should be used by the tests.""")
+                        help="""Specify which network with external
+                                connectivity should be used by the tests.""")
+    parser.add_argument('--network',
+                        help="""Specify which network (id/name) with external
+                                connectivity should be used by the tests.""")
     parser.add_argument('--append', action='append', default=[],
                         metavar="SECTION.KEY=VALUE[,VALUE]",
                         help="""Append values to tempest.conf
@@ -355,6 +363,12 @@ def parse_arguments():
     if args.test_accounts and args.create_accounts_file:
         raise Exception("Options '--test-accounts' and "
                         "'--create-accounts-file' can't be used together.")
+    if args.network_id and args.network:
+        raise Exception("--network-id is deprecated and will be replaced with"
+                        " --network. Please, use only --network argument.")
+    if args.network_id:
+        LOG.warning("The --network-id is deprecated, please, use --network")
+        args.network = args.network_id
     args.overrides = parse_overrides(args.overrides)
     return args
 
@@ -457,6 +471,9 @@ def set_cloud_config_values(non_admin, cloud_creds, conf):
                      'project_name',
                      cloud_creds['project_name'])
             conf.set('identity', 'password', cloud_creds['password'])
+            for cred in ['project_domain_name', 'user_domain_name']:
+                if cred in cloud_creds:
+                    conf.set('auth', cred, cloud_creds[cred])
         else:
             # admin credentials are under auth section
             conf.set('auth', 'admin_username', cloud_creds['username'])
@@ -464,6 +481,12 @@ def set_cloud_config_values(non_admin, cloud_creds, conf):
                      'admin_project_name',
                      cloud_creds['project_name'])
             conf.set('auth', 'admin_password', cloud_creds['password'])
+            for cred in [
+                'domain_name', 'project_domain_name', 'user_domain_name'
+            ]:
+                if cred in cloud_creds:
+                    conf.set('auth', f'admin_{cred}', cloud_creds[cred])
+
         conf.set('identity', 'uri', cloud_creds['auth_url'])
 
         if 'region_name' in cloud_creds:
@@ -495,10 +518,15 @@ def get_cloud_creds(args_namespace):
 
     cloud_creds = cloud.config.get_auth_args()
     region_name = cloud.config.config['region_name']
-
     if region_name:
         cloud_creds['region_name'] = region_name
 
+    request_args = cloud.config.get_requests_verify_args()
+    cloud_creds['request_args'] = {
+        'verify': request_args[0],
+        'cert': request_args[1],
+    }
+
     return cloud_creds
 
 
@@ -519,14 +547,17 @@ def config_tempest(**kwargs):
                 accounts_path,
                 kwargs.get('cloud_creds'))
 
-    credentials = Credentials(conf, not kwargs.get('non_admin', False))
+    request_args = kwargs.get('cloud_creds', {}).get('request_args', {})
+    credentials = Credentials(conf, not kwargs.get('non_admin', False),
+                              **request_args)
     clients = ClientManager(conf, credentials)
-    services = Services(clients, conf, credentials)
 
     if kwargs.get('create', False) and kwargs.get('test_accounts') is None:
         users = Users(clients.projects, clients.roles, clients.users, conf)
         users.create_tempest_users()
 
+    services = Services(clients, conf, credentials)
+
     if services.is_service(**{"type": "compute"}):
         flavors = Flavors(clients.flavors, kwargs.get('create', False), conf,
                           kwargs.get('flavor_min_mem', C.DEFAULT_FLAVOR_RAM),
@@ -542,11 +573,12 @@ def config_tempest(**kwargs):
                                     no_rng=kwargs.get('no_rng', False),
                                     convert=kwargs.get('convert_to_raw',
                                                        False))
-        image.create_tempest_images(conf)
+        retry_alt = kwargs.get('retry_image', False)
+        image.create_tempest_images(conf, retry_alt=retry_alt)
 
     if services.is_service(**{"type": "network"}):
         network = services.get_service("network")
-        network.create_tempest_networks(conf, kwargs.get('network_id'))
+        network.create_tempest_networks(conf, kwargs.get('network'))
 
     services.post_configuration()
     services.set_supported_api_versions()
@@ -594,7 +626,7 @@ def main():
         flavor_min_disk=args.flavor_min_disk,
         image_disk_format=args.image_disk_format,
         image_path=args.image,
-        network_id=args.network_id,
+        network=args.network,
         non_admin=args.non_admin,
         no_rng=args.no_rng,
         os_cloud=args.os_cloud,
@@ -602,7 +634,8 @@ def main():
         overrides=args.overrides,
         remove=args.remove,
         test_accounts=args.test_accounts,
-        verbose=args.verbose
+        verbose=args.verbose,
+        retry_image=args.retry_image
     )
 
 
